@@ -10,7 +10,7 @@ Primary
 </name>
 
 <description>  
-Primary. Includes: gcompris, laby, lybniz, ri-li, stellarium, tuxmath, tuxpaint, tuxtype, and marble
+Primary. Includes: gcompris, laby, ri-li, stellarium, tuxmath, tuxpaint, tuxtype, and marble
 </description>
 
 <installable>
@@ -25,9 +25,7 @@ all
 
 <install_package_names>
 gcompris
-gcompris-sound-en
 laby
-lybniz
 ri-li
 stellarium
 tuxmath
@@ -45,9 +43,7 @@ marble-plugins
 
 <uninstall_package_names>
 gcompris
-gcompris-sound-en
 laby
-lybniz
 ri-li
 stellarium
 tuxmath
